﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Windows;
using System.Windows.Media.Imaging;
using Microsoft.Win32;
using Syncfusion.UI.Xaml.Charts;

namespace Testing_WFP_Charts
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            var therapyStartDate = new DateTime(2015, 2, 1);
            var rampInDate = new DateTime(2014, 11, 1);
            var rampOutDate = new DateTime(2016, 9, 1);

            List<ChartDataItem> datapoints = new List<ChartDataItem>();
            datapoints.Add(new ChartDataItem() { X = "2000", Val0 = 30 });
            datapoints.Add(new ChartDataItem() { X = "2001", Val0 = 33 });
            datapoints.Add(new ChartDataItem() { X = "2002", Val0 = 10 });

            var lineSerie = new LineSeries();
            lineSerie.Label = "Some Header";
            lineSerie.XBindingPath = "X";
            lineSerie.YBindingPath = "Val0";
            lineSerie.EnableAnimation = false;
            lineSerie.ShowTooltip = true;

            lineSerie.ItemsSource = datapoints;

            var adornment = new ChartAdornmentInfo();
            adornment.Symbol = ChartSymbol.Plus;
            adornment.SymbolHeight = 8;
            adornment.SymbolWidth = 8;
            adornment.ShowMarker = true;
            
            lineSerie.LegendIcon = ChartLegendIcon.Rectangle;
            lineSerie.AdornmentsInfo = adornment;
            
            linechart.Series.Add(lineSerie);

            this.ViewModel = new ChartVm
            {
                ChartTitle = "TestTitle",
                Maximum = 100,
                Minimum = 0,
                Datapoints = new ObservableCollection<ChartDataItem>(datapoints)
          };


            this.DataContext = this.ViewModel;
        }

        public ChartVm ViewModel { get; set; }

        private void But_Export_Click(object sender, RoutedEventArgs e)
        {
            //MyChart.Save("chart_image.png");

            SaveFileDialog sfd = new SaveFileDialog();
            sfd.FileName = "Untitled";
            sfd.Filter = "PNG(*.png)|*.png|Bitmap(*.bmp)|*.bmp|JPEG(*.jpg,*.jpeg)|*.jpg;*.jpeg|Gif (*.gif)|*.gif|All files (*.*)|*.*";
            if (sfd.ShowDialog() == true)
            {
                using (Stream fs = sfd.OpenFile())
                {
                    linechart.Save(fs, new PngBitmapEncoder());
                }
            }
        }

        private void ButClose_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }
    }

    public class ChartVm
    {
        public int Maximum { get; set; }

        public int Minimum { get; set; }

        public System.Collections.ObjectModel.ObservableCollection<ChartDataItem> Datapoints { get; set; }

        public int? SecondaryAxisMinimum { get; set; }

        public string XHeaderText { get; set; }

        public string YHeaderText { get; set; }

        public string ChartTitle { get; set; }
    }

    public class ChartDataItem
    {
        public string X { get; set; }

        public string Y { get; set; }

        public double? Val0 { get; set; }
        public double? Val1 { get; set; }
    }

    public class RangeAreaChartDataItem
    {
        public DateTime Date { get; set; }
        public decimal? High { get; set; }
        public decimal? Low { get; set; }
    }

}
